@@ -61,7 +61,7 @@ Fully Automatic Installation
 Flash Authority Identification Data (EEPROM)
 
 @item FAIS
-Finnish Artificial Intelligence Society (org., Finland, AI), http://www.uwasa.fi/stes/eindex.html
+Finnish Artificial Intelligence Society (org., Finland, AI)
 
 @item FAL
 File Access Listener (DEC, DNA)
@@ -76,7 +76,7 @@ Floating gate Avalanche injection Metal Oxide Semiconductor (IC)
 Fast Amsterdam MultiProcessor
 
 @item FANP
-Flow Attribute Notification Protocol (Toshiba, RFC 2129), ftp://ftp.rfc-editor.org/in-notes/rfc2129.txt
+Flow Attribute Notification Protocol (Toshiba, RFC 2129)
 
 @item FAP
 Flight Attendant Panel (Airbus, A380, CIDS, LCD)
@@ -115,7 +115,7 @@ Fast ARM Solutions Toolkit (ARM, Palm, PDA)
 First Application System Test
 
 @item FAST
-Forschungsinstitut fuer Angewandte Software-Technologie [e.v.] (org.), http:/www.fast.de
+Forschungsinstitut fuer Angewandte Software-Technologie [e.v.] (org.)
 
 @item FAT
 File Allocation Table (DOS)
@@ -127,10 +127,10 @@ Fibre-Attached Technology Adapted (HP, SATA, HDD)
 Flow Admission Update [message] (LFAP)
 
 @item FAU
-Friedrich-Alexander-Universitaet (org., Erlangen, Germany, Nuernberg, Germany), http://www.uni-erlangen.de
+Friedrich-Alexander-Universitaet (org., Erlangen, Germany, Nuernberg, Germany)
 
 @item FAW
-Forschungsinstitut fuer Anwendungsorientierte Wissensverarbeitung (org., KI, Ulm), http://merlin.faw.uni-ulm.de/faw
+Forschungsinstitut fuer Anwendungsorientierte Wissensverarbeitung (org., KI, Ulm)
 
 @item FAXP
 FAX Profile (Bluetooth, SPP), "FaxP"
@@ -180,6 +180,9 @@ Fault, Configuration, Accounting, Performance, Security [management areas]
 @item FCB
 File Control Block (DOS)
 
+@item FCBB
+Fibre Channel BackBone (FCP), "FC-BB"
+
 @item FCBS
 File Control BlockS (DOS)
 
@@ -187,7 +190,7 @@ File Control BlockS (DOS)
 Fast Communication Controller (SCC, MCC)
 
 @item FCC
-Federal Communications Commission (org., USA), http://www.fcc.gov
+Federal Communications Commission (org., USA)
 
 @item FCC
 Forward Carbon Copy (telecommunication)
@@ -196,7 +199,7 @@ Forward Carbon Copy (telecommunication)
 Frequency Correction CHannel (GSM, mobile-systems)
 
 @item FCCN
-Fundacao para a Computacao Cientifica Nacional (org., Portugal), http://www.fccn.pt
+Fundacao para a Computacao Cientifica Nacional (org., Portugal)
 
 @item FCD
 Floating Car Data
@@ -226,7 +229,7 @@ Flow Control Indicator (DLSW)
 Forward Cache Identifier (CATNIP)
 
 @item FCIA
-Fibre Channel Industry Association (org.), http://fibrechannel.org/
+Fibre Channel Industry Association (org.)
 
 @item FCIP
 Fibre Channel over Internet Protocol (SAN, FC, IP)
@@ -240,6 +243,9 @@ Fibre Channel Methodology for Interconnects (FC, SAN, ANSI), "FC-MI"
 @item FCO
 Flow Control Operator Bits (DLSW, BIT)
 
+@item FCOE
+Fibre Channel Over Ethernet, "FCoE"
+
 @item FCOS
 Flip Chip on Substrate
 
@@ -331,7 +337,7 @@ Flat Display Mounting Interface (VESA, MIS)
 Functional Device Object
 
 @item FDSN
-Federation of Digital Seismograph Networks (org.), http://www.fdsn.org/
+Federation of Digital Seismograph Networks (org.)
 
 @item FDT
 Formal Description Technique
@@ -388,7 +394,7 @@ Finite Elemente Methode
 Free-net Erlangen/Nuernberg
 
 @item FEP
-Firewall Enhancement Protocol (RFC 3093), ftp://ftp.rfc-editor.org/in-notes/rfc3093.txt
+Firewall Enhancement Protocol (RFC 3093)
 
 @item FEP
 Flight Envelope Protection (Airbus, A380)
@@ -403,7 +409,7 @@ Forward Error Correction (satellite)
 Far End Receive Failure (UNI, ATM, SONET, OAM)
 
 @item FESI
-Federacion Espanola de Sociedades de Informatica (org., Spain), http://www.fesi.fi.upm.es/
+Federacion Espanola de Sociedades de Informatica (org., Spain)
 
 @item FET
 Field Effect Transistor
@@ -472,7 +478,7 @@ File system Hierarchy Standard (Linux, LSB)
 Frequency Hopping Spread Spectrum (WLAN)
 
 @item FIA
-Fiberoptic Industry Association (org.), http://www.netwales.co.uk/fia/welcome.htm
+Fiberoptic Industry Association (org.)
 
 @item FIB
 Forwarding Information Base (router, LAN, Internet)
@@ -481,7 +487,7 @@ Forwarding Information Base (router, LAN, Internet)
 FInanzBUchhaltung
 
 @item FIC
-First International Computer [inc.] (manufacturer), http://www.fic.com.tw
+First International Computer [inc.] (manufacturer)
 
 @item FICS
 Free Internet Chess Server
@@ -493,7 +499,7 @@ File IDentifier (APDU)
 File Identifier Descriptor (UDF, CD-R)
 
 @item FIDO
-Fast IDentity Online (org.), http://fidoalliance.org/
+Fast IDentity Online (org.)
 
 @item FIDO
 FIlter Device Object, "FiDO"
@@ -514,7 +520,7 @@ Forth Interest Group (org., Forth)
 Frank, Ian and Glenn's LETters (ASCII, fonts)
 
 @item FILE
-Free Internet Lexicon and Encyclopedia (WWW, DICT), http://www.dict.org/file.html
+Free Internet Lexicon and Encyclopedia (WWW, DICT)
 
 @item FILO
 First In Last Out
@@ -568,10 +574,10 @@ Federal Internet Requirements Panel (Internet, USA)
 Federated Internet Registry Service (LDAP, Internet)
 
 @item FIRST
-ForschungsInstitut fuer Rechnerarchitektur und SoftwareTechnik (org., GMD, Berlin, Germany), http://www.gmd.de/first/firsthome.html
+ForschungsInstitut fuer Rechnerarchitektur und SoftwareTechnik (org., GMD, Berlin, Germany)
 
 @item FIRST
-Forum of Incident Response and SecuriTy (org., NIST), http://first.org
+Forum of Incident Response and SecuriTy (org., NIST)
 
 @item FIS
 FachInformationsSystem
@@ -595,13 +601,13 @@ Fraunhofer institut fuer angewandte InformationsTechnik (org.)
 Functional Interpolating Transformation System
 
 @item FITUG
-Foerderverein Informationstechnik und Gesellschaft [e.V.] (org.), http://www.fitug.de
+Foerderverein Informationstechnik und Gesellschaft [e.V.] (org.)
 
 @item FIU
 Fingerprint Identification Unit (Sony)
 
 @item FIZ
-FachInformationsZentrum karlsruhe Org., Germany, http://www.fiz-karlsruhe.de
+FachInformationsZentrum karlsruhe Org., Germany
 
 @item FK
 Foundation Kit (NextStep, OpenStep, Apple, Rhapsody)
@@ -688,14 +694,17 @@ FachNormenausschuss Informationsverarbeitung [1962-1987] (DIN, NI, predecessor)
 Fiber Optic
 
 @item FOA
-Fiber Optic Association (org.), http://www.std.com/fotec/foa.htm
+Fiber Optic Association (org.)
 
 @item FOAF
-Friend Of A Friend [vocabulary] (RDF), http://www.foaf-project.org/
+Friend Of A Friend [vocabulary] (RDF)
 
 @item FOC
 Fiber Optic Cable / Communications
 
+@item FOCAL
+FOrmula CALculator
+
 @item FOCS
 [symposium on] Foundations Of Computer Science (Konferenz)
 
@@ -709,16 +718,16 @@ Formal specification of ODA document structures (ODA, ISO)
 [international conference on] Foundations Of Data Organization and algorithms (conference, INRIA)
 
 @item FOEBUD
-[verein zur] Foerderung des OEffentlichen Bewegten und Unbewegten Datenverkehrs [e.v.] (org.), "FoeBuD", http://www.foebud.org
+[verein zur] Foerderung des OEffentlichen Bewegten und Unbewegten Datenverkehrs [e.v.] (org.), "FoeBuD"
 
 @item FOIRL
 Fiber Optic InterRepeater Link (OWG)
 
 @item FOKUS
-Forschungszentrum fuer Offene KommUnikationsSysteme (org., GMD, Berlin, Germany), http://www.fokus.gmd.de
+Forschungszentrum fuer Offene KommUnikationsSysteme (org., GMD, Berlin, Germany)
 
 @item FOLDOC
-Free OnLine Dictionary Of Computing (WWW, UK), http://wombat.doc.ic.ac.uk
+Free OnLine Dictionary Of Computing (WWW, UK)
 
 @item FOLED
 Flexible Organic Light Emitting Display (OLED)
@@ -736,7 +745,7 @@ Fiber Optics Network
 Friends Of O'reilly [meeting]
 
 @item FOOBAR
-FTP Operation Over Big Address Records (RFC 1639, FTP), ftp://ftp.rfc-editor.org/in-notes/rfc1639.txt
+FTP Operation Over Big Address Records (RFC 1639, FTP)
 
 @item FOOT
 Forum for Object Oriented Technology (CERN, OOP)
@@ -745,7 +754,7 @@ Forum for Object Oriented Technology (CERN, OOP)
 Feature Orientated Programming
 
 @item FOP
-Formatting Object Processor (Apache, XSL-FO), http://xml.apache.org/fop/
+Formatting Object Processor (Apache, XSL-FO)
 
 @item FORMEX
 FORMalised EXchange of electronic publications (SGML, Europe)
@@ -757,10 +766,10 @@ Formal Object Role Modelling Language
 FORmula TRANslation
 
 @item FORTWIHR
-FORschungsverbund fuer Technisch-WIssenschaftliches HochleistungsRechnen (org., Bavaria), http://www5.informatik.tu-muenchen.de/forschung/fortwihr
+FORschungsverbund fuer Technisch-WIssenschaftliches HochleistungsRechnen (org., Bavaria)
 
 @item FORWISS
-bayerisches FORschungszentrum fuer WISsensbasierte Systeme (org., KI), http://www.forwiss.tu-muenchen.de, http://www.fmi.uni-passau.de/forwiss/uebersicht.html
+bayerisches FORschungszentrum fuer WISsensbasierte Systeme (org., KI)
 
 @item FOSI
 Format Output Specification Instance (SGML, CALS)
@@ -769,7 +778,7 @@ Format Output Specification Instance (SGML, CALS)
 Free and Open Source Software
 
 @item FOSSFA
-Free Software and Open Source Foundation for Africa (org., Africa), http://www.fossfa.net/
+Free Software and Open Source Foundation for Africa (org., Africa)
 
 @item FOSSIL
 Fido Opus Seadog Standard Interface Layer
@@ -826,7 +835,7 @@ Floating Point Engine
 Field Programmable Function Array
 
 @item FPGA
-Field Programmable Gate Array (RL), http://www.mrc.uidaho.edu/fpga/fpga.html
+Field Programmable Gate Array (RL)
 
 @item FPI
 Flux Changes per Inch (HDD)
@@ -948,6 +957,9 @@ Frame Relay Service (ATM, UNI)
 @item FS
 File System (LVM)
 
+@item FS
+Forward Secrecy (cryptography, PFS)
+
 @item FS
 Frame Status (FDDI, Token Ring)
 
@@ -970,13 +982,13 @@ File System Consistency checK (Unix)
 File System Driver
 
 @item FSF
-Free Software Foundation (org., GNU), http://www.gnu.org
+Free Software Foundation (org., GNU)
 
 @item FSFE
-Free Software Foundation Europe (org., FSF), http://www.fsfeurope.org
+Free Software Foundation Europe (org., FSF)
 
 @item FSG
-Free Standards Group (org.), http://www.freestandards.org
+Free Standards Group (org.)
 
 @item FSH
 File System Hierarchy (Linux, LSB)
@@ -1011,6 +1023,9 @@ Free Standing Operating System (OS)
 @item FSP
 File Slurping Protocol
 
+@item FSPF
+Fibre channel Shortest Path First
+
 @item FSRM
 File Server Resource Manager (AD)
 
@@ -1084,7 +1099,7 @@ File Transfer Open Systems
 File Transfer OSI Support
 
 @item FTP
-File Transfer Protocol (Internet, RFC 959), ftp://ftp.rfc-editor.org/in-notes/rfc959.txt
+File Transfer Protocol (Internet, RFC 959)
 
 @item FTP
 Foiled Twisted Pair [cable] (UTP, TP)
@@ -1126,7 +1141,7 @@ FernmeldeTechnische Zentralamt / Zulassung (DTAG, ZZF, predecessor)
 Flow Update Acknowledge [message] (LFAP)
 
 @item FUB
-Freie Universitaet Berlin (org.), http://www.inf.fu-berlin.de
+Freie Universitaet Berlin (org.)
 
 @item FUBAB
 Fouled / Fucked Up Beyond All Belief (slang, Usenet, IRC)
@@ -1140,6 +1155,9 @@ Fouled / Fucked Up Beyond All Recognition / Repair (slang, Usenet, IRC)
 @item FUD
 Fear, Uncertainty & Doubt (slang, IBM)
 
+@item FUHD
+Full Ultra HD [7680x4320] (HD)
+
 @item FUN
 Flow Update Notification [message] (LFAP)
 
@@ -1165,7 +1183,7 @@ FirmWare Hub (BIOS, Intel)
 For What It's Worth (slang, Usenet, IRC)
 
 @item FWS
-Folding White Space (RFC 1822), ftp://ftp.rfc-editor.org/in-notes/rfc1822.txt
+Folding White Space (RFC 1822)
 
 @item FWT
 Fast Wavelet Transformation
@@ -1186,7 +1204,7 @@ For Your Information (slang, Usenet, IRC)
 ??? [compression]
 
 @item FZI
-ForschungsZentrum Informatik (org., Uni Karlsruhe, Germany), http://www.fzi.de
+ForschungsZentrum Informatik (org., Uni Karlsruhe, Germany)
 
 @end table
 
