@@ -58,10 +58,10 @@ Message Address Directory
 Militaerischer AbschirmDienst (mil., org.)
 
 @item MADCAP
-Multicast Address Dynamic Client Allocation Protocol (RFC 2730, Multicast), ftp://ftp.rfc-editor.org/in-notes/rfc2730.txt
+Multicast Address Dynamic Client Allocation Protocol (RFC 2730, Multicast)
 
 @item MADE
-Multimedia Application Development Environment (CWI), http://www.cwi.nl/cwi/projects/made.html
+Multimedia Application Development Environment (CWI)
 
 @item MADK
 Microsoft Activex Development Kit (ActiveX, MS)
@@ -70,13 +70,13 @@ Microsoft Activex Development Kit (ActiveX, MS)
 Multiple APIC Description Table (ACPI, APIC)
 
 @item MAE
-Macintosh Application Environment (Apple, Sun, HPUX), http://www.mae.apple.com
+Macintosh Application Environment (Apple, Sun, HPUX)
 
 @item MAE
 Metropolitan Area Exchange (Internet)
 
 @item MAEC
-Malware Attribute Enumeration and Characterization, http://maec.mitre.org/
+Malware Attribute Enumeration and Characterization
 
 @item MAINSAIL
 MAchine INdependent SAIL (SAIL)
@@ -124,7 +124,7 @@ Multimedia APplications in Education Conference, "MApEC"
 Messaging Application Program Interface (MS, WOSA, API)
 
 @item MAPOS
-Multiple Access Protocol over SONET/SDH (SONET, SDH, RFC 2171), ftp://ftp.rfc-editor.org/in-notes/rfc2171.txt
+Multiple Access Protocol over SONET/SDH (SONET, SDH, RFC 2171)
 
 @item MAPP
 Microsoft Active Protections Program (MS)
@@ -157,7 +157,7 @@ Multi Agent Systems (AI)
 Mittelstands-Anwendungs-System 90 (IBM)
 
 @item MASC
-Multicast Address-Set Claim [protocol] (RFC 2909, Multicast), ftp://ftp.rfc-editor.org/in-notes/rfc2909.txt
+Multicast Address-Set Claim [protocol] (RFC 2909, Multicast)
 
 @item MASE
 Message Administration Service Element
@@ -178,7 +178,7 @@ Medium Attachment Unit (IEEE 802.3, Transceiver)
 Multistation Access Unit (Token Ring, Hub)
 
 @item MAUS
-Muensters Apple User Service (BBS, network), "M.A.U.S.", http://www.maus.de
+Muensters Apple User Service (BBS, network), "M.A.U.S."
 
 @item MAW
 Microsoft At Work
@@ -223,7 +223,7 @@ Mega Binary digIT (BIT), "MBit"
 Media Bandwidth Management (DSL, Zyxel)
 
 @item MBOA
-MultiBand OFDM Alliance (org., OFDM), http://www.multibandofdm.org
+MultiBand OFDM Alliance (org., OFDM)
 
 @item MBPS
 MegaBits Per Second (BIT)
@@ -237,6 +237,9 @@ Maximum Burst Size
 @item MBSA
 Microsoft Baseline Security Analyzer (MS, Windows)
 
+@item MBSA
+Microsoft Business and Services Agreement (MS)
+
 @item MBUS
 Module BUS [standard] (Sun, SPARC), "MBus"
 
@@ -292,10 +295,10 @@ Media Center Edition (MS, Windows, XP, OEM)
 Military Communications-Electronics Board (org., mil., USA)
 
 @item MCERT
-Mittelstand Computer Emergency Response Team Germany, http://www.mcert.de
+Mittelstand Computer Emergency Response Team Germany
 
 @item MCF
-Meta Content Framework / Format (Apple, WWW), http://mcf.research.apple.com
+Meta Content Framework / Format (Apple, WWW)
 
 @item MCF
 MOM Connector Framework (MS, MOM)
@@ -313,10 +316,10 @@ Measurement Layer Interface (UMA)
 Media Control Interface
 
 @item MCI
-Microwave Communications Incorporated, http://www.mci.com
+Microwave Communications Incorporated
 
 @item MCL
-Media Communication Lab (org., Uni Boston, USA), http://spiderman.bu.edu
+Media Communication Lab (org., Uni Boston, USA)
 
 @item MCM
 Multi Carrier Modulation
@@ -328,7 +331,7 @@ MultiChip Module (CPU)
 Metropolitan Campus Network
 
 @item MCNE
-Master Certified Netware Engineer (Novell, Netware), http://www.novell.com/education/mcne/
+Master Certified Netware Engineer (Novell, Netware)
 
 @item MCNS
 Multimedia Cable Network System (org.)
@@ -427,13 +430,13 @@ Management Domain
 Mini Disk (Sony)
 
 @item MD2
-Message Digest [algorithm] 2 (RFC 1115/1319), ftp://ftp.rfc-editor.org/in-notes/rfc1319.txt, ftp://ftp.rfc-editor.org/in-notes/rfc1115.txt
+Message Digest [algorithm] 2 (RFC 1115/1319)
 
 @item MD4
-Message Digest [algorithm] 4 (RFC 1320), ftp://ftp.rfc-editor.org/in-notes/rfc1320.txt
+Message Digest [algorithm] 4 (RFC 1320)
 
 @item MD5
-Message Digest [algorithm] 5 (RFC 1321), ftp://ftp.rfc-editor.org/in-notes/rfc1321.txt
+Message Digest [algorithm] 5 (RFC 1321)
 
 @item MDA
 Mail Delivery Agent
@@ -448,7 +451,7 @@ Mobile Digital Assistant (T-Mobile, PDA)
 Model Driven Architecture (CASE, OMG)
 
 @item MDA
-Monochrome Display Adapter (IBM, PC)
+Monochrome Display Adapter [720x350] (IBM, PC)
 
 @item MDAC
 Microsoft Data Access Components (MS)
@@ -460,7 +463,7 @@ Multidimensional DataBase Management System (DBMS, DB)
 Micro Data Base System (DB)
 
 @item MDC
-Message conversion system directory Component (MCS)
+Message conversion system Directory Component (MCS)
 
 @item MDC
 Meta Data Coalition
@@ -484,7 +487,7 @@ Menu DEfinition Functions (Apple, CDEF)
 Medium Dependent Interface (ethernet)
 
 @item MDI
-Mobile Data Initiative (org., GSM, mobile-systems), http://www.gsmdata.com
+Mobile Data Initiative (org., GSM, mobile-systems)
 
 @item MDI
 Multiple Document Interface (MS, Windows)
@@ -564,6 +567,9 @@ MEgaBInary [(2^10)^2] (IEC)
 @item MEC
 Memory Expansion Card
 
+@item MEC
+Microsoft Exchange Conference (MS)
+
 @item MEF
 Managed Extensibility Framework (MS)
 
@@ -598,7 +604,7 @@ Menue-EntwicklungsSystem (Sinix, SNI)
 Minimum European Set (UTF, ISO 10646)
 
 @item MESA
-MetaEmailSearchAgent (WWW, Internet), http://mesa.rrzn.uni-hannover.de/
+MetaEmailSearchAgent (WWW, Internet)
 
 @item MESCH
 Multi-WAIS Engine for Searching Commercial Hosts (WAIS, WWW)
@@ -640,7 +646,7 @@ Middle European Time Daylight Saving Time [+0200] (TZ, MET, MEZ)
 Multiformat Engine Unit (LCD, Sony)
 
 @item MEWDE
-My EMACS Web Development Environment (EMACS, WWW), http://mewde.blogspot.com
+My EMACS Web Development Environment (EMACS, WWW)
 
 @item MEZ
 MittelEuropaeische [sommer] Zeit [+0200] (TZ)
@@ -649,7 +655,7 @@ MittelEuropaeische [sommer] Zeit [+0200] (TZ)
 Multi Frequency
 
 @item MFAST
-Mwave Folded Array Signal Transform [DSP] (IBM, DSP), http://watson.mbb.sfu.ca
+Mwave Folded Array Signal Transform [DSP] (IBM, DSP)
 
 @item MFC
 Memory Flow Controller (SPE, Cell, IBM)
@@ -721,7 +727,7 @@ Matrox Graphics Adapter (Matrox)
 Monochrome Graphics Adapter
 
 @item MGCP
-Media Gateway Control Protocol (VoIP, RFC 2705), ftp://ftp.rfc-editor.org/in-notes/rfc2705.txt
+Media Gateway Control Protocol (VoIP, RFC 2705)
 
 @item MGI
 Multi-Function Interpreter
@@ -748,7 +754,7 @@ Mobile High-definition Link
 [columbia] Mobile Host Protocol
 
 @item MHP
-Multimedia Home Platform (ETSI), http://www.mhp-forum.de
+Multimedia Home Platform (ETSI)
 
 @item MHPCC
 Maui High Performance Computing Center (org., USA)
@@ -760,7 +766,7 @@ Message Handling System (GOSIP, X.400, Novell, SPX, IPX)
 Messaging HyperText Markup Language (HTML)
 
 @item MHTML
-MIME [e-mail encapsulation of aggregate documents, such as] HTML (MIME, HTML, RFC 2110), ftp://ftp.rfc-editor.org/in-notes/rfc2110.txt
+MIME [e-mail encapsulation of aggregate documents, such as] HTML (MIME, HTML, RFC 2110)
 
 @item MI
 Management Interface
@@ -799,7 +805,7 @@ MODEM ISDN Channel Integration (Telebit, MODEM, ISDN)
 Modular Integrated Communications Environment
 
 @item MICO
-MICO Is CORBA (ORB, CORBA, Uni Frankfurt), http://diamant-atm.vsb.cs.uni-frankfurt.de/~mico
+MICO Is CORBA (ORB, CORBA, Uni Frankfurt)
 
 @item MID
 Message IDentifier (ATM)
@@ -811,7 +817,7 @@ Mobile Information Device
 Multiple Interface Declaration (OLSR)
 
 @item MIDI
-Musical Instruments Digital Interface (MIDI), http://www.midi.org
+Musical Instruments Digital Interface (MIDI)
 
 @item MIDL
 Microsoft Interface Definition Language (NT)
@@ -856,7 +862,7 @@ Military STandarD (mil., USA), "MIL-STD"
 Multiple Instruction [stream], Multiple Data [stream] (CPU)
 
 @item MIME
-Multipurpose Internet Mail Extensions (RFC 2045/2046/2047/2048/2049, IETF), ftp://ftp.rfc-editor.org/in-notes/rfc2045.txt, ftp://ftp.rfc-editor.org/in-notes/rfc2046.txt
+Multipurpose Internet Mail Extensions (RFC 2045/2046/2047/2048/2049, IETF)
 
 @item MIMO
 Multiple Input, Multiple Output (WLAN)
@@ -934,28 +940,31 @@ Multiple Input, Single Output (WLAN)
 Motor Industry Software Reliability Association (UK)
 
 @item MISS
-Mecklenburg Internet Service System (ISP), http://www.miss.net
+Mecklenburg Internet Service System (ISP)
 
 @item MISSI
 Multilevel Information System Security Initiative (org.)
 
 @item MISX
-Metered Services Information eXchange (Internet), http://www.msix.org
+Metered Services Information eXchange (Internet)
 
 @item MIT
 Management Information Tree
 
 @item MIT
-Massachusetts Institute of Technology (org., USA), http://www.lcs.mit.edu, http://www.ai.mit.edu
+Massachusetts Institute of Technology (org., USA)
 
 @item MIT
 Mobile Internet Toolkit (MS, .NET)
 
+@item MITM
+Man In The Middle [[attack]]
+
 @item MJ
 Modular Jack
 
 @item MKS
-Mortice Kern Systems (manufacturer), http://www.mks.com
+Mortice Kern Systems (manufacturer)
 
 @item MKT
 Multifunktionelles KartenTerminal (CT, ICC)
@@ -982,7 +991,7 @@ Micro Lens Array
 Multi Level Cell (IC, PCMCIA, Flash, Intel, SLC)
 
 @item MLD
-Multicast Listener Discovery [protocol] (IPV6, Multicast, RFC 2710), ftp://ftp.rfc-editor.org/in-notes/rfc2710.txt
+Multicast Listener Discovery [protocol] (IPV6, Multicast, RFC 2710)
 
 @item MLE
 MultiLine Entry field (IBM, OS/2)
@@ -994,7 +1003,7 @@ Measurement Layer Interface (UMA)
 Multiple Link Interface (ODI)
 
 @item MLIA
-[symposium on] Machine Learning in Information Access (AAAI, AI, conference), http://www.parc.xerox.com/istl/projects/mlia
+[symposium on] Machine Learning in Information Access (AAAI, AI, conference)
 
 @item MLID
 Multiple Link Interface Driver (ODI, LAN)
@@ -1036,7 +1045,7 @@ Military Message (mil.)
 Mobile Management (RR, CM, GSM, mobile-systems)
 
 @item MMA
-Microcomputer Managers Association (org., USA), http://www.midi.org
+Microcomputer Managers Association (org., USA)
 
 @item MMA
 MIDI Manufacturer Association (org., IMA)
@@ -1066,7 +1075,7 @@ MultiMedia Compact Disk (Sony, Philips, CD)
 MultiMedia Compact Disk - Erasable (Sony, Philips, CD), "MMCD-E"
 
 @item MMCF
-MultiMedia Communications Forum (org.), http://www.mmcf.org
+MultiMedia Communications Forum (org.)
 
 @item MMDO
 Magnetic Modulation Direct Overwrite
@@ -1120,7 +1129,7 @@ Modified Modified Read (Fax)
 Mobile Multi-hop Relay Study Group (IEEE), "MMR SG"
 
 @item MMS
-Manufacturing Message Specifications / Standard (MAP, EIA, RS-511, ISO, DIS 9506), http://icawww.epfl.ch/MMS/
+Manufacturing Message Specifications / Standard (MAP, EIA, RS-511, ISO, DIS 9506)
 
 @item MMS
 Maximum Message Size
@@ -1236,6 +1245,9 @@ high data rate MObile interNET (network)
 @item MOO
 MUD Object Orientated (Internet, OOP, MUD)
 
+@item MOOC
+Massive Open Online Course (Internet)
+
 @item MOP
 Maintenance Operations Protocol (DEC)
 
@@ -1246,7 +1258,7 @@ Meta Object Protocol (CLOS)
 Multiple Original Prints
 
 @item MOPRIA
-MObile PRinting Alliance (org., Canon, HP, Samsung, Xerox), http://www.mopria.org/
+MObile PRinting Alliance (org., Canon, HP, Samsung, Xerox)
 
 @item MOPS
 Million Operations Per Second
@@ -1266,6 +1278,9 @@ Minimum Operating System (OS, UNIVAC 9200, UNIVAC 9300)
 @item MOS
 Multiprogramming Operating System (OS, NCR)
 
+@item MOSA
+Microsoft Online Subscription Agreement (MS)
+
 @item MOSES
 Major Open Systems Environment Standards
 
@@ -1273,13 +1288,13 @@ Major Open Systems Environment Standards
 Metal Oxide Semiconductor Field Effect Transistor (IC, FET)
 
 @item MOSIX
-Multicomputer Operating System for UnIX (Unix, Cluster, MOSIX), http://www.mosix.org
+Multicomputer Operating System for UnIX (Unix, Cluster, MOSIX)
 
 @item MOSP
 Microsoft Online Services Partnership (MSN)
 
 @item MOSPF
-Multicast [extensions to ] Open Shortest Path First [routing] (IP, OSPF, RFC 1584), ftp://ftp.rfc-editor.org/in-notes/rfc1584.txt
+Multicast [extensions to ] Open Shortest Path First [routing] (IP, OSPF, RFC 1584)
 
 @item MOSRO
 MObiles-Sicherheits-ROboter-System
@@ -1288,7 +1303,7 @@ MObiles-Sicherheits-ROboter-System
 Media Orientated Systems Transport
 
 @item MOST
-Mobile Open Systems Technologies (UK, Uni Lancaster), http://www.lancs.ac.uk/computing/research/mpq/projects.html#MOST
+Mobile Open Systems Technologies (UK, Uni Lancaster)
 
 @item MOT
 Means of Test
@@ -1315,7 +1330,7 @@ Microsoft Overlay Virtual Environment (MS)
 Magneto-Optical Write Once Read Many, "MO-WORM" 
 
 @item MP
-[PPP] Multilink Protocol (MPPP, RFC 1990), ftp://ftp.rfc-editor.org/in-notes/rfc1990.txt
+[PPP] Multilink Protocol (MPPP, RFC 1990)
 
 @item MP
 Management Pack (MS, MOM)
@@ -1330,7 +1345,7 @@ Multi Processor
 MultiProtocol
 
 @item MP3
-MPEG audio layer 3 (MPEG, audio, IIS, ISO), http://www.mp3.com
+MPEG audio layer 3 (MPEG, audio, IIS, ISO)
 
 @item MPC
 Modular Port Concentrator
@@ -1360,7 +1375,7 @@ Multi-Programming Executive (OS, HP, HP 3000)
 Motion Picture Expert Group [old term] (MPEG)
 
 @item MPEG
-Moving Picture Expert Group (org., ISO 11172-1, JTC1), http://www.cselt.it/mpeg
+Moving Picture Expert Group (org., ISO 11172-1, JTC1)
 
 @item MPEGTS
 Moving Picture Expert Group - Transport Stream (MPEG, TS), MPEG-TS
@@ -1387,7 +1402,7 @@ Message Passing Interface Forum (manufacturer)
 Mozilla Public License (Netscape)
 
 @item MPLS
-Multi-Protocol Label Switching (RFC 3031), ftp://ftp.rfc-editor.org/in-notes/rfc3031.txt
+Multi-Protocol Label Switching (RFC 3031)
 
 @item MPM
 Metra Potential Method
@@ -1420,22 +1435,22 @@ Multiple Purpose Operator Workstation
 Massive Parallel Processor / Processing (MPP)
 
 @item MPP
-Message Posting Protocol (RFC 1204), ftp://ftp.rfc-editor.org/in-notes/rfc1204.txt
+Message Posting Protocol (RFC 1204)
 
 @item MPP
 Message Processing Program
 
 @item MPPC
-Microsoft Point-to-Point Compression (MS, RFC 2118), ftp://ftp.rfc-editor.org/in-notes/rfc2118.txt
+Microsoft Point-to-Point Compression (MS, RFC 2118)
 
 @item MPPD
 Multi Purpose Peripheral Device
 
 @item MPPE
-Microsoft Point to Point Encryption (MS, cryptography, RFC 3078), ftp://ftp.rfc-editor.org/in-notes/rfc3078.txt
+Microsoft Point to Point Encryption (MS, cryptography, RFC 3078)
 
 @item MPPP
-Multilink Point-to-Point Protocol (PPP, RFC 1990, MP, Ascend), ftp://ftp.rfc-editor.org/in-notes/rfc1990.txt
+Multilink Point-to-Point Protocol (PPP, RFC 1990, MP, Ascend)
 
 @item MPR
 Maet- och Provningsradet [National Board for Measurement and Testing] (org., Sweden, SWEDAC)
@@ -1458,6 +1473,9 @@ MultiPage Signal (Fax)
 @item MPS
 MultiProcessor Specification (SMP, Intel)
 
+@item MPSA
+Microsoft Products and Services Agreement (MS)
+
 @item MPSX
 Mathematical Programming System eXtended (IBM)
 
@@ -1558,7 +1576,7 @@ Macintosh Runtime for Java Software Developer Kit (Apple, Java), "MRJ SDK"
 Multi Resolution Meshes (Intel, 3D)
 
 @item MRML
-Multimedia Retrieval Markup Language (Multimedia, Internet, XML), http://www.mrml.net
+Multimedia Retrieval Markup Language (Multimedia, Internet, XML)
 
 @item MRNET
 Minnesota Regional NETwork (network, USA)
@@ -1615,7 +1633,7 @@ Message Store
 Meta Signaling (ATM, ???)
 
 @item MS
-MicroSoft (manufacturer, MS), http://www.microsoft.com, http://www.microsoft.de
+MicroSoft (manufacturer, MS)
 
 @item MS
 Mobile Station (GSM, mobile-systems)
@@ -1693,7 +1711,7 @@ MicroSoft Developer Network Academic Alliance (MS)
 MicroSoft Disk Operating System (MS, OS, PC)
 
 @item MSDP
-Multicast Source Discovery Protocol (Internet, PIM-SM, Multicast, RFC 3618), ftp://ftp.rfc-editor.org/in-notes/rfc3618.txt
+Multicast Source Discovery Protocol (Internet, PIM-SM, Multicast, RFC 3618)
 
 @item MSE
 Mean Squared Error
@@ -1729,7 +1747,7 @@ Medium Scale Integration
 MicroSoft Installer (MS, WIndows)
 
 @item MSI
-Micro-Star International (manufacturer, Taiwan), http://www.msi.com.tw
+Micro-Star International (manufacturer, Taiwan)
 
 @item MSIE
 MicroSoft Internet Explorer (MS, WWW, MSIE)
@@ -1741,7 +1759,7 @@ MicroSoft Intermediate Language (MS, .NET, CLI)
 Mobile Station ISDN Number (PLMN, GSM, mobile-systems), "MS-ISDN"
 
 @item MSIX
-Metered Services Information eXchange [protocol] (Internet, ISP), http://www.msix.org
+Metered Services Information eXchange [protocol] (Internet, ISP)
 
 @item MSJVM
 MicroSoft Java Virtual Machine (MS, Java)
@@ -1786,7 +1804,7 @@ Media Signal Processor (Samsung, MMX, ARM)
 Message Security Protocol
 
 @item MSP
-Message Send Protocol (RFC 1159), ftp://ftp.rfc-editor.org/in-notes/rfc1159.txt
+Message Send Protocol (RFC 1159)
 
 @item MSP
 Multitasking System Program (OS, Hemenway)
@@ -1842,6 +1860,9 @@ Message Submission Service Element
 @item MST
 Mountain Standard Time [-0700] (TZ, MDT, USA)
 
+@item MSTP
+Multiple Spanning Tree Protocol (STP, VLAN, IEEE 802.1s)
+
 @item MSTSC
 MicroSoft Terminal Services Client (MS)
 
@@ -1924,7 +1945,7 @@ Modulation Transfer Function
 Memory Translator Hub (Intel)
 
 @item MTI
-MIPS Technologies Inc. (manufacturer, SGI), http://www.mips.com
+MIPS Technologies Inc. (manufacturer, SGI)
 
 @item MTJ
 Magnetic Tunnel Junction (MRAM)
@@ -2017,13 +2038,16 @@ MULTiplexed Information and Computing Service (OS, MIT, Bell)
 MULtimedia Office Server (OA, BIS, ESPRIT)
 
 @item MUMPS
-Massachusetts general hospital Multi-Programming System
+Massachusetts general hospital Utility Multi-Programming System
 
 @item MUMPS
 Multi-User Multi-Programming System ??? (OS, DEC)
 
+@item MUMPS
+MUMPS Development Committee (org., MUMPS)
+
 @item MUPAD
-Multi Processing Algebra Data [tool] (Uni Paderborn, Germany, CAS), "MuPAD", http://math-www.uni.paderborn.de/~cube
+Multi Processing Algebra Data [tool] (Uni Paderborn, Germany, CAS), "MuPAD"
 
 @item MUSH
 Multi-User Shared Hallucination (MUD)
@@ -2071,7 +2095,7 @@ Multi-Vendor Interacting Forum (org., IN)
 Most Valuable Professional [bonus program] (MS)
 
 @item MVRCA
-Magnalink Variable Resource Compression Algorithm (PPP, RFC 1975), ftp://ftp.rfc-editor.org/in-notes/rfc1975.txt
+Magnalink Variable Resource Compression Algorithm (PPP, RFC 1975)
 
 @item MVS
 Multiple Virtual Storage (IBM, OS, OS/MVS)
@@ -2134,7 +2158,7 @@ MobilitY DisplayPort, "MyDP"
 Mark Zbikowski (MS-DOS, MCB)
 
 @item MZAP
-Multicast-scope Zone Announcement Protocol (RFC 2776, Multicast), ftp://ftp.rfc-editor.org/in-notes/rfc2776.txt
+Multicast-scope Zone Announcement Protocol (RFC 2776, Multicast)
 
 @end table
 
